#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# File name          : create_db.py
# Author             : Podalirius (@podalirius_)
# Date created       : 2 Aug 2021

import argparse
import os
import sqlite3
import names
import random
from rich.progress import track


def pseudo_exists(cursor, username):
    cursor.execute("SELECT username FROM users WHERE username LIKE ? ", (username + "%",))
    rows = cursor.fetchall()
    return bool(len(rows) != 0)


def generate(cursor):
    firstname, lastname = names.get_full_name().split(' ', 1)
    username = firstname.lower() + '.' + lastname.lower()
    k = 0
    if pseudo_exists(cursor, username):
        username = username + "%d"
        while pseudo_exists(cursor, username % k):
            k += 1
        username = username % k
    age = random.randint(21, 95)
    return username, firstname, lastname, age


def parseArgs():
    parser = argparse.ArgumentParser(description="Description message")
    parser.add_argument("-f", "--file", required=False, default="database.db", help='arg1 help message')
    parser.add_argument("-n", "--number", required=False, default=4500, type=int, help='Number of entries to generate')
    parser.add_argument("-v", "--verbose", required=False, default=False, action="store_true", help='Verbose mode')
    return parser.parse_args()


if __name__ == '__main__':
    options = parseArgs()

    if os.path.exists(options.file):
        os.remove(options.file)

    # Create schema
    conn = sqlite3.connect(options.file)
    cursor = conn.cursor()
    cursor.execute("""CREATE TABLE users(id INTEGER PRIMARY KEY AUTOINCREMENT, username TEXT, firstname TEXT, lastname TEXT, age INTEGER)""")
    conn.commit()

    # Populate data
    for k in track(range(options.number), description="Populating database"):
        username, firstname, lastname, age = generate(cursor)
        if options.verbose == True:
            print("[>] Adding %s, %s, %s, %d" % (username, firstname, lastname, age))
        cursor.execute("""INSERT INTO users VALUES(NULL, ?, ?, ?, ?)""", (username, firstname, lastname, age))
        conn.commit()
    conn.close()
